==> validation-model-jakarta-1.29.15-sources.jar: org/verapdf/gf/model/impl/pd/gfse/contents/GFSELineArtItem.java <==
/**
 * This file is part of veraPDF Validation for Jakarta EE, a module of the veraPDF project.
 * Copyright (c) 2015-2025, veraPDF Consortium <info@verapdf.org>
 * All rights reserved.
 *
 * veraPDF Validation for Jakarta EE is free software: you can redistribute it and/or modify
 * it under the terms of either:
 *
 * The GNU General public license GPLv3+.
 * You should have received a copy of the GNU General Public License
 * along with veraPDF Validation for Jakarta EE as the LICENSE.GPL file in the root of the source
 * tree.  If not, see http://www.gnu.org/licenses/ or
 * https://www.gnu.org/licenses/gpl-3.0.en.html.
 *
 * The Mozilla Public License MPLv2+.
 * You should have received a copy of the Mozilla Public License along with
 * veraPDF Validation for Jakarta EE as the LICENSE.MPL file in the root of the source tree.
 * If a copy of the MPL was not distributed with this file, you can obtain one at
 * http://mozilla.org/MPL/2.0/.
 */
package org.verapdf.gf.model.impl.pd.gfse.contents;

import org.verapdf.gf.model.impl.operator.pathpaint.GFOpPathPaint;
import org.verapdf.model.selayer.SELineArtItem;

/**
 * @author Maxim Plushchov
 */
public class GFSELineArtItem extends GFSESimpleContentItem implements SELineArtItem {

    public static final String LINE_ART_ITEM_TYPE = "SELineArtItem";

    private static final String LINE_ART_CONTENT_ITEM_TYPE = "lineArt";

    private final GFOpPathPaint opPathPaint;

    public GFSELineArtItem(GFOpPathPaint opPathPaint, GFSEGroupedContent groupedContent) {
        super(LINE_ART_ITEM_TYPE, groupedContent);
        this.opPathPaint = opPathPaint;
    }

    @Override
    public String getitemType() {
        return LINE_ART_CONTENT_ITEM_TYPE;
    }
}

==> validation-model-jakarta-1.29.114-sources.jar: org/verapdf/gf/model/impl/pd/gfse/contents/GFSELineArtItem.java <==
/**
 * This file is part of veraPDF Validation for Jakarta EE, a module of the veraPDF project.
 * Copyright (c) 2015-2025, veraPDF Consortium <info@verapdf.org>
 * All rights reserved.
 *
 * veraPDF Validation for Jakarta EE is free software: you can redistribute it and/or modify
 * it under the terms of either:
 *
 * The GNU General public license GPLv3+.
 * You should have received a copy of the GNU General Public License
 * along with veraPDF Validation for Jakarta EE as the LICENSE.GPL file in the root of the source
 * tree.  If not, see http://www.gnu.org/licenses/ or
 * https://www.gnu.org/licenses/gpl-3.0.en.html.
 *
 * The Mozilla Public License MPLv2+.
 * You should have received a copy of the Mozilla Public License along with
 * veraPDF Validation for Jakarta EE as the LICENSE.MPL file in the root of the source tree.
 * If a copy of the MPL was not distributed with this file, you can obtain one at
 * http://mozilla.org/MPL/2.0/.
 */
package org.verapdf.gf.model.impl.pd.gfse.contents;

import org.verapdf.gf.model.impl.operator.pathpaint.GFOpPathPaint;
import org.verapdf.model.selayer.SELineArtItem;

/**
 * @author Maxim Plushchov
 */
public class GFSELineArtItem extends GFSEGraphicContentItem implements SELineArtItem {

    public static final String LINE_ART_ITEM_TYPE = "SELineArtItem";

    private static final String LINE_ART_CONTENT_ITEM_TYPE = "lineArt";

    private final GFOpPathPaint opPathPaint;

    public GFSELineArtItem(GFOpPathPaint opPathPaint, GFSEGroupedContent groupedContent) {
        super(LINE_ART_ITEM_TYPE, groupedContent);
        this.opPathPaint = opPathPaint;
    }

    @Override
    public String getitemType() {
        return LINE_ART_CONTENT_ITEM_TYPE;
    }
}
